import { Connect, Datasource, Message } from '@genesislcap/foundation-comms';
import { FASTElement } from '@microsoft/fast-element';
import { Subscription } from 'rxjs';
import { AlertConfig } from '../config/config';
import { AlertRule, AlertRuleRow } from './main.types';
type displayState = 'add' | 'edit' | 'list';
/**
 * Foundation alerts component for handle alerts rules list
 * Allow creating, disabling and deleting alerts
 * @beta
 */
export declare class FoundationAlerts extends FASTElement {
    connect: Connect;
    datasource: Datasource;
    displayState: displayState;
    items: AlertRule[];
    alertEditItemData: AlertRule;
    alertConfig: AlertConfig;
    private sourceRef;
    private resourceName;
    private statusLabelMap;
    dataSubscription: Subscription;
    ready: boolean;
    filters: {
        name: string;
        callback: () => void;
        icon: {
            name: string;
        };
    }[];
    criteriaFromFilters: Map<string, string>;
    criteriaFromFiltersChanged(): void;
    connectedCallback(): Promise<void>;
    disconnectedCallback(): void;
    private findIndexAlertByRef;
    private fetchData;
    private handleStreamUpdate;
    private handleInserts;
    private handleDeletes;
    private handleUpdates;
    private buildCriteria;
    private setFilter;
    private removeFilter;
    delete(id: AlertRuleRow['DYNAMIC_NOTIFY_RULE_ID']): Promise<Message>;
    toogleStatus({ RULE_STATUS, DYNAMIC_NOTIFY_RULE_ID: ID, }: AlertRuleRow): Promise<Message>;
    handleAddAlertAction(): void;
    handleEditAlertAction(item: any): void;
}
/**
 * ZeroAlerts.
 *
 * @remarks
 * A zero version that pre-registers zero components and uses the zero design system. ZeroAlerts and its components won't bloat the core bundle as
 * these are only loaded on-demand when in use.
 *
 * @example
 * ```ts
 * import { ZeroAlerts } from '@genesislcap/foundation-alerts';
 * ...
 * ZeroAlerts
 * ```
 *
 * @example Load the micro frontend on-demand
 * ```ts

 *   const { ZeroAlerts } = await import('@genesislcap/foundation-alerts');
 *   return ZeroAlerts;
 * },
 * ```
 *
 * @public
 */
export declare class ZeroAlerts extends FoundationAlerts {
    /**
     * @internal
     */
    connectedCallback(): Promise<void>;
    /**
     * @internal
     */
    protected loadRemotes(): Promise<void>;
}
export {};
//# sourceMappingURL=main.d.ts.map